@@ -1,4 +1,4 @@
-iamb.gammabs <- function(target, dataset, threshold = 0.05, wei = NULL, heavy = FALSE) {
+iamb.gammabs <- function(target, dataset, threshold = 0.05, wei = NULL) {
   
   threshold <- log(threshold)
   dm <- dim(dataset)
@@ -7,8 +7,9 @@ iamb.gammabs <- function(target, dataset, threshold = 0.05, wei = NULL, heavy =
   if ( p > n ) {
     res <- paste("The number of variables is hiher than the sample size. No backward procedure was attempted")
   } else {
-
-    a1 <- internaliamb.gammabs( target = target, dataset = dataset, threshold = threshold, wei = wei, p = p, heavy = heavy ) 
+    
+    dataset <- as.data.frame(dataset)
+    a1 <- internaliamb.gammabs( target = target, dataset = dataset, threshold = threshold, wei = wei, p = p  ) 
     ind <- 1:p
     a2 <- list()
     poies <- a1$mat[, 1]
@@ -16,7 +17,7 @@ iamb.gammabs <- function(target, dataset, threshold = 0.05, wei = NULL, heavy =
       ind[-poies] <- 0
       ind <- ind[ind > 0]
       dat <- dataset[, poies ]
-      a2 <- internaliamb.gammabs( target = target, dataset = dat, threshold = threshold, wei = wei, p = length(ind), heavy = heavy ) 
+      a2 <- internaliamb.gammabs( target = target, dataset = dat, threshold = threshold, wei = wei, p = length(ind) ) 
       poies <- a2$mat[, 1]
       ind[-poies] <- 0
       ind <- ind[ind > 0]
@@ -29,7 +30,7 @@ iamb.gammabs <- function(target, dataset, threshold = 0.05, wei = NULL, heavy =
     while ( length(a1$mat[, 1]) - length(a2$mat[, 1]) != 0 ) {
       i <- i + 1
       a1 <- a2
-      a2 <- internaliamb.gammabs( target = target, dataset = dat, threshold = threshold, wei = wei, p = length(ind), heavy = heavy ) 
+      a2 <- internaliamb.gammabs( target = target, dataset = dat, threshold = threshold, wei = wei, p = length(ind) ) 
       poies <- a2$mat[, 1]
       if ( length(poies) > 0 ) {
         ind[-poies] <- 0
